@@ -118,6 +118,7 @@ theme_vbar <-
 #' @param y_scale_zero TRUE or FALSE of whether the minimum of the y scale is zero. Defaults to TRUE.
 #' @param y_scale_trans A string specifying a transformation for the y axis scale, such as "log10" or "sqrt". Defaults to "identity".
 #' @param pal Character vector of hex codes. Defaults to NULL, which selects the Stats NZ palette.
+#' @param width Width of bars. Defaults to 0.75.
 #' @param title Title string. Defaults to [Title].
 #' @param subtitle Subtitle string. Defaults to [Subtitle].
 #' @param x_title X axis title string. Defaults to [X title].
@@ -155,6 +156,7 @@ ggplot_vbar <- function(data,
                         y_scale_zero = TRUE,
                         y_scale_trans = "identity",
                         pal = NULL,
+                        width = 0.75, 
                         title = "[Title]",
                         subtitle = NULL,
                         x_title = "[X title]",
@@ -205,9 +207,8 @@ ggplot_vbar <- function(data,
       font_size_title = font_size_title
     )
   
-  if (lubridate::is.Date(x_var_vector)) width <- 365 * 0.75
-  else if (is.numeric(x_var_vector)) width <- 0.75
-  
+  if (lubridate::is.Date(x_var_vector)) width <- 365 * width
+
   if (is.null(rlang::get_expr(hover_var))) {
     plot <- plot +
       geom_col(aes(text = paste(
@@ -336,6 +337,7 @@ ggplot_vbar <- function(data,
 #' @param position Whether bars are positioned by "stack" or "dodge". Defaults to "stack".
 #' @param pal Character vector of hex codes. Defaults to NULL, which selects the Stats NZ palette.
 #' @param legend_ncol The number of columns in the legend.
+#' @param width Width of bars. Defaults to 0.75.
 #' @param title Title string. Defaults to [Title].
 #' @param subtitle Subtitle string. Defaults to [Subtitle].
 #' @param x_title X axis title string. Defaults to [X title].
@@ -379,6 +381,7 @@ ggplot_vbar_col <-
            position = "stack",
            pal = NULL,
            legend_ncol = 3,
+           width = 0.75, 
            title = "[Title]",
            subtitle = NULL,
            x_title = "[X title]",
@@ -443,8 +446,7 @@ ggplot_vbar_col <-
         font_size_title = font_size_title
       )
     
-    if (lubridate::is.Date(x_var_vector)) width <- 365 * 0.75
-    else if (is.numeric(x_var_vector)) width <- 0.75
+    if (lubridate::is.Date(x_var_vector)) width <- 365 * width
     
     if (is.null(rlang::get_expr(hover_var))) {
       plot <- plot +
@@ -616,6 +618,7 @@ ggplot_vbar_col <-
 #' @param facet_scales Whether facet_scales should be "fixed" across facets, "free" in both directions, or free in just one direction (i.e. "free_x" or "free_y"). Defaults to "fixed".
 #' @param facet_nrow The number of rows of facetted plots. Defaults to NULL, which generally chooses 2 rows. Not applicable to where isMobile is TRUE.
 #' @param pal Character vector of hex codes. Defaults to NULL, which selects the Stats NZ palette.
+#' @param width Width of bars. Defaults to 0.75.
 #' @param title Title string. Defaults to [Title].
 #' @param subtitle Subtitle string. Defaults to [Subtitle].
 #' @param x_title X axis title string. Defaults to [X title].
@@ -656,6 +659,7 @@ ggplot_vbar_facet <-
            facet_scales = "fixed",
            facet_nrow = NULL,
            pal = NULL,
+           width = 0.75, 
            title = "[Title]",
            subtitle = NULL,
            x_title = "[X title]",
@@ -709,8 +713,7 @@ ggplot_vbar_facet <-
         font_size_title = font_size_title
       )
     
-    if (lubridate::is.Date(x_var_vector)) width <- 365 * 0.75
-    else if (is.numeric(x_var_vector)) width <- 0.75
+    if (lubridate::is.Date(x_var_vector)) width <- 365 * width
     
     if (is.null(rlang::get_expr(hover_var))) {
       plot <- plot +
@@ -869,6 +872,7 @@ ggplot_vbar_facet <-
 #' @param facet_nrow The number of rows of facetted plots. Defaults to NULL, which generally chooses 2 rows. Not applicable to where isMobile is TRUE.
 #' @param pal Character vector of hex codes. Defaults to NULL, which selects the Stats NZ palette.
 #' @param legend_ncol The number of columns in the legend.
+#' @param width Width of bars. Defaults to 0.75.
 #' @param title Title string. Defaults to [Title].
 #' @param subtitle Subtitle string. Defaults to [Subtitle].
 #' @param x_title X axis title string. Defaults to [X title].
@@ -920,6 +924,7 @@ ggplot_vbar_col_facet <-
            facet_nrow = NULL,
            pal = NULL,
            legend_ncol = 3,
+           width = 0.75, 
            title = "[Title]",
            subtitle = NULL,
            x_title = "[X title]",
@@ -984,9 +989,8 @@ ggplot_vbar_col_facet <-
         font_size_title = font_size_title
       )
     
-    if (lubridate::is.Date(x_var_vector)) width <- 365 * 0.75
-    else if (is.numeric(x_var_vector)) width <- 0.75
-
+    if (lubridate::is.Date(x_var_vector)) width <- 365 * width
+    
     if (is.null(rlang::get_expr(hover_var))) {
       plot <- plot +
         geom_col(aes(
